from fastapi import HTTPException


class HandlingResponse:
    valid: bool
    data: dict
    error: str
    codeError: int
    defaultError: dict

    def __init__(self, valid, data=None, error=None, code_error=None):
        if valid and data is None:
            data = {"status": "ok"}

        self.data = data
        self.error = error
        self.codeError = code_error
        self.valid = valid

    def get(self, key):
        if self.data[key]:
            return self.data[key]
        return False

    def get_error_response(self):
        code_error = self.codeError if self.codeError != '' else '520'
        error = self.error if self.error != '' else self.get_default_errors(code_error)
        return HTTPException(status_code=code_error, detail=error)

    @staticmethod
    def get_default_errors(code):
        errors_dict = {
            "404": "not_found",
            "401": "invalid_token",
            "500": "internal_server_error",
            "520": "unknown_error",
        }
        return errors_dict[code]



"""Setup for read env"""
from setuptools import setup

requirements = [
    'fastapi>=0.70.0',
]

setup(
    name='py-handling-response',
    version='0.1.2',
    license='MIT',
    description='py handing response for fast api responses from functions and classes',
    author='liuspatt',
    author_email='liuspatt@handlingresponse.com',
    url='https://github.com/liuspatt/py-handling-response',
    keywords=['env', 'python', 'windows'],
    install_requires=requirements,
    python_requires=">=3.5",
    packages=['handlingresponse'],
    package_dir={'': 'src'},
    package_data={
        'handlingresponse': ['py.typed'],
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Topic :: System :: Systems Administration',
        'Topic :: Utilities',
        'Environment :: Web Environment',
    ],
)
